@@ -19,7 +19,7 @@
 #ifndef GAMESELECTIONSCENE_H
 #define GAMESELECTIONSCENE_H
 
-#include <QtCore/QSignalMapper>
+#include <QSignalMapper>
 #include <QGraphicsScene>
 
 
@@ -30,7 +30,7 @@ class GameSelectionScene : public QGraphicsScene
     class GameSelectionBox;
 
 public:
-    GameSelectionScene( QObject * parent );
+    explicit GameSelectionScene( QObject * parent );
     ~GameSelectionScene();
 
     void resizeScene( const QSize & size );
